==> tekton-model-triggers-v1alpha1-6.5.1-sources.jar: io/fabric8/tekton/triggers/internal/knative/pkg/apis/duck/v1alpha1/AddressableFluentImpl.java <==
package io.fabric8.tekton.triggers.internal.knative.pkg.apis.duck.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class AddressableFluentImpl<A extends AddressableFluent<A>> extends BaseFluent<A> implements AddressableFluent<A>{
  public AddressableFluentImpl() {
  }
  public AddressableFluentImpl(Addressable instance) {
    this.withHostname(instance.getHostname()); 
    this.withUrl(instance.getUrl()); 
  }
  private String hostname;
  private String url;
  public String getHostname() {
    return this.hostname;
  }
  public A withHostname(String hostname) {
    this.hostname=hostname; return (A) this;
  }
  public Boolean hasHostname() {
    return this.hostname != null;
  }
  public String getUrl() {
    return this.url;
  }
  public A withUrl(String url) {
    this.url=url; return (A) this;
  }
  public Boolean hasUrl() {
    return this.url != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    AddressableFluentImpl that = (AddressableFluentImpl) o;
    if (hostname != null ? !hostname.equals(that.hostname) :that.hostname != null) return false;
    if (url != null ? !url.equals(that.url) :that.url != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(hostname,  url,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (hostname != null) { sb.append("hostname:"); sb.append(hostname + ","); }
    if (url != null) { sb.append("url:"); sb.append(url); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> tekton-model-triggers-v1alpha1-6.7.2-sources.jar: io/fabric8/tekton/triggers/internal/knative/pkg/apis/duck/v1alpha1/AddressableFluentImpl.java <==
package io.fabric8.tekton.triggers.internal.knative.pkg.apis.duck.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class AddressableFluentImpl<A extends AddressableFluent<A>> extends BaseFluent<A> implements AddressableFluent<A>{
  public AddressableFluentImpl() {
  }
  public AddressableFluentImpl(Addressable instance) {
    if (instance != null) {
      this.withHostname(instance.getHostname());
      this.withUrl(instance.getUrl());
    }
  }
  private String hostname;
  private String url;
  public String getHostname() {
    return this.hostname;
  }
  public A withHostname(String hostname) {
    this.hostname=hostname; return (A) this;
  }
  public Boolean hasHostname() {
    return this.hostname != null;
  }
  public String getUrl() {
    return this.url;
  }
  public A withUrl(String url) {
    this.url=url; return (A) this;
  }
  public Boolean hasUrl() {
    return this.url != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    AddressableFluentImpl that = (AddressableFluentImpl) o;
    if (!java.util.Objects.equals(hostname, that.hostname)) return false;

    if (!java.util.Objects.equals(url, that.url)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(hostname,  url,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (hostname != null) { sb.append("hostname:"); sb.append(hostname + ","); }
    if (url != null) { sb.append("url:"); sb.append(url); }
    sb.append("}");
    return sb.toString();
  }
  
}
